
# Disabling the Telem Plugin

## What will happen?

While it will not possible to recover telemetry data later,
    you can backup or copy over existing records to another database.
    To do so, find the **Copy Telemetry Data** operation in the app's
    Operations page.

## What if I change my mind?

While it will not possible to recover telemetry data later,
    you can backup or copy over existing records to another database.
    To do so, find the **Copy Telemetry Data** operation in the app's
    Operations page.
    
## Actually, I only want to change storage types 

While it will not possible to recover telemetry data later,
    you can backup or copy over existing records to another database.
    To do so, find the **Copy Telemetry Data** operation in the app's
    Operations page.

## How does this affect NMachine telemetry?

Destroy resources associated with telemetry persistence,
    then re-apply the manifest



# The 3 Different storage strategies